% --------------------------STATE EQUATIONS-------------------------- 

function dxdt=IMcurf0(t,x,Rs,Rr,Lm, Lsl,Lrl,Vs,wo,km,H,Bm,TLi,TLf,init)

        % State variable vector
        %                x=[ids iqs idr iqr wm psi]
        
  wm=x(5) ;          % speed
  psi=x(6);          % reference frame position with respect to stator
       if km==1, wk=0; end
       if km==2, wk=1.0; end
       if km==3, wk=wm; end
  % ---------------------- INPUTS -----------------------------------------     
  %  Load profile :    
        if init==1, TL=TLi;
        elseif init==2 & t<0.4, TL=TLi;
        elseif init==2 & t>=0.4 & t<1.0, TL=TLf;  
        elseif init==2 & t>1.0, TL=TLi;    
        end    
  %  Stator voltage profile  :  
   vas=Vs*cos(wo*t);    vbs=Vs*sin(wo*t); % Stator 2-phase voltage excitation in stator frame
 % ------------------------------------------------------------------------
  vds= vas*cos(psi)+vbs*sin(psi) ;
  vqs=-vas*sin(psi)+vbs*cos(psi) ;       % Stator voltage excitation in common reference frame
 
    V=[vds vqs 0 0]';                    % Voltage vector
    I=[x(1) x(2) x(3) x(4)]';            % Current vector
    
    R=diag([Rs Rs Rr Rr]);               % Resistance matrix   
    
   Ls=Lsl+Lm ; Lr=Lrl+Lm;
   L=[Ls  0   Lm  0   
      0   Ls  0   Lm 
      Lm  0   Lr  0
      0   Lm  0   Lr];                   % Inductance matrix
    
    W=[0        -wk         0        0
      wk         0          0        0
       0         0          0     -(wk-wm)
       0         0       (wk-wm)     0   ]; % Frame speed matrix
   
    Q=R+W*L;  
    
    Te=Lm*(x(2)*x(3)-x(1)*x(4));  % Electromagnetic torque
    
  %%% Matrix formulation of induction machine equations in common reference frame  
  %%% F = L*I   or I = L\F
  %%% V= R*I + W*F + dF/wodt = R*I + W*L*I +dF/wodt = (R + W*L)*I + L*dI/wodt      
  
   didt=L\(V-Q*I)*wo;              % Electrical system equations
   dwmdt=(Te-TL)/(2*H)-.5*Bm/H*wm; % Mechanical system equation
   dxdt=[didt;dwmdt;wk*wo];        % State equations
% ------------------------------------------------------------------