% --------------------------STATE EQUATIONS-------------------------- 

function dxdt=SMabcf7(t,x,Ra,Rf,Rkd,Rkq,Ls,Lal,Lf,Lkd,Lkq,Vm,vf1,vf2,wo,H,Bm,TL1,TL2,tf,t1,t2)

  % ---------------------- INPUTS -----------------------------------------   
                                                                                     % Select input A or B:                                    
    %if t<t1, TL=TL1;  else TL=TL2; end                                              % A==>   active power step command 
     if t<t1, TL=TL1;  elseif  t>t1 & t<tf-1, TL=TL1-.25*(t-t1);
                                                   else TL=TL1-.25*(tf-1-t1); end     % B==>   active power ramp command 
   
     if t<t2, vf=vf1;  else vf=vf2; end                                              % C==>   reactive power command
            
      gam=2*pi/3;
     vas=Vm*cos(wo*t);    vbs=Vm*cos(wo*t-gam);  vcs=Vm*cos(wo*t+gam);
   
   % ------------------------------------------------------------------------
         %                State variable vector
         %                x=[ias ibs ics iff ikd ikq wm theta]'
   Lm=Ls-Lal; 
                   
   wm=x(7) ;          % speed
   theta=x(8);        % angle
   
    V=[vas vbs vcs vf 0 0]';                    % Voltage vector
    I=x(1:6) ;                                  % Current vector
    
    R=diag([Ra Ra Ra Rf Rkd Rkq]);              % Resistance matrix   
    
    
   % Inductance matrices :
       Lss=[Ls    -Lm/2  -Lm/2    
           -Lm/2   Ls    -Lm/2
           -Lm/2  -Lm/2   Ls];  
         
         Lfkd=1.0; Laf=1.0; Lakd=1.0; Lakq=1.0;  
             
    Lrr=[Lf   Lfkd  0 
        Lfkd   Lkd  0
          0     0  Lkq]; 
      
    Lsr=[Laf*cos(theta)     Lakd* cos(theta)     -Lakq*sin(theta)
         Laf*cos(theta-gam) Lakd*cos(theta-gam)  -Lakq*sin(theta-gam)
         Laf*cos(theta+gam) Lakd*cos(theta+gam)  -Lakq*sin(theta+gam)];
    
    dLsr=[-Laf*sin(theta)     -Lakd*sin(theta)      -Lakq*cos(theta)
          -Laf*sin(theta-gam) -Lakd*sin(theta-gam)  -Lakq*cos(theta-gam)
          -Laf*sin(theta+gam) -Lakq*sin(theta+gam)  -Lakq*cos(theta+gam)];
      
     L=[Lss  Lsr                     
        Lsr' Lrr];                   % Inductance matrix
       
    dLdtheta=[zeros(3)    dLsr         
              dLsr'    zeros(3)];    % dL/dtheta
                   
        
    Te=0.5*I'*dLdtheta*I ;           % Electromagnetic torque
 
  %%% Matrix formulation of synchronous machine equations expressed in abc phase variables 
  %%% Constitutive flux-current relations:
  %%%    F = L*I   or  I = L\F  
  %%% Electrical system equations:
  %%%    V= R*I + dF/wodt = R*I + d(L*I)/wodt = (R + wm*dL/dtheta)*I + L*dI/wodt  
  %%% Mechanical system equation:
  %%%    Te = 2*H*dwm/dt + TL + Bm*wm
  %%%                                     see refs. 14 -- 23
  
   didt=L\(V-(R+wm*dLdtheta)*I)*wo;       % Electrical system equations
   dwmdt=(Te-TL)/(2*H)-Bm*wm/(2*H);       % Mechanical system equation
   
   dxdt=[didt;dwmdt;wm*wo];               % State equations arrived at by concatenation
   
 %%% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  