% --------------------------STATE EQUATIONS-------------------------- 

function dxdt=SMabcstabeq5(t,x,Ra,Rf,Rkd,Rkq,Ld,Lq,Lal,Lf,Lkd,Lkq,Vm,wo,H,Bm,TL,vf,to,tc)

  % ---------------------- INPUTS -----------------------------------------     
      % SH=1 ;   
      % Initial run to establish IC's at specified steady-state loading with no fault
      
     if t<to, SH=1; elseif t>to & t<to+tc, SH=0; else SH=1;  end      % Short circuit run
     
     gam=2*pi/3;
     vas=SH*Vm*cos(wo*t);    vbs=SH*Vm*cos(wo*t-gam);  vcs=SH*Vm*cos(wo*t+gam);
   
   % ----------------------------------------------------------------------
            % State variable vector
         %                x=[ias ibs ics iff ikd ikq wm theta]
   Lad=Ld-Lal;   Laq=Lq-Lal;
   L2=(Lad-Laq)/2;
   Lm=(Lad+Laq)/2;
   Lao=Lm+Lal;   Labo=-0.5*Lm; 
                   
   wm=x(7) ;          % speed
   theta=x(8);        % angle
   
    V=[vas vbs vcs vf 0 0]';                    % Voltage vector
    I=x(1:6) ;                                  % Current vector
    
    R=diag([Ra Ra Ra Rf Rkd Rkq]);              % Resistance matrix   
    
     % Inductance matrices :
      Laa=Lao+L2*cos(2*theta);           Lab=Labo+L2*cos(2*theta-gam);
      Lbb=Lao+L2*cos(2*(theta-gam));     Lbc=Labo+L2*cos(2*theta);
      Lcc=Lao+L2*cos(2*(theta+gam));     Lac=Labo+L2*cos(2*theta+gam);
           
    Lss=[Laa   Lab Lac   
         Lab   Lbb Lbc 
         Lac   Lbc Lcc]; 
    
            Lfkd=1.0; Laf=1.0; Lakd=1.0; Lakq=1.0;  
             
    Lrr=[Lf   Lfkd  0 
        Lfkd   Lkd  0
          0     0  Lkq]; 
      
    Lsr=[Laf*cos(theta)     Lakd* cos(theta)     -Lakq*sin(theta)
         Laf*cos(theta-gam) Lakd*cos(theta-gam)  -Lakq*sin(theta-gam)
         Laf*cos(theta+gam) Lakd*cos(theta+gam)  -Lakq*sin(theta+gam)];
    
     dLss=-2*L2*[sin(2*theta)       sin(2*theta-gam)  sin(2*theta+gam)  
                  sin(2*theta-gam) sin(2*(theta-gam))    sin(2*theta)
                  sin(2*theta+gam)   sin(2*theta)    sin(2*(theta+gam))];  
         
    dLsr=[-Laf*sin(theta)     -Lakd*sin(theta)      -Lakq*cos(theta)
          -Laf*sin(theta-gam) -Lakd*sin(theta-gam)  -Lakq*cos(theta-gam)
          -Laf*sin(theta+gam) -Lakq*sin(theta+gam)  -Lakq*cos(theta+gam)];
      
     L=[Lss  Lsr                     
        Lsr' Lrr];                   % Inductance matrix
       
    dLdtheta=[dLss     dLsr         
              dLsr'    zeros(3)];    % dL/dtheta
                   
        
    Te=0.5*I'*dLdtheta*I ;           % Electromagnetic torque
 
  %%% Matrix formulation of synchronous machine equations in abc stationary reference frame| 
  %%% Constitutive flux-current relations:
  %%%    F = L*I   or  I = L\F  
  %%% Electrical system equations:
  %%%    V= R*I + dF/wodt = R*I + d(L*I)/wodt = (R + wm*dL/dtheta)*I + L*dI/wodt  
  %%% Mechanical system equation:
  %%%    Te = 2*H*dwm/dt + TL + Bm*wm
    
   didt=L\(V-(R+wm*dLdtheta)*I)*wo;       % Electrical system equations
   dwmdt=(Te-TL)/(2*H)-Bm*wm/(2*H);       % Mechanical system equation
   
   dxdt=[didt;dwmdt;wm*wo];               % State equations arrived at by concatenation
   
 %%% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  