%SMtransientscript.m  SYNCHRONOUS MACHINE TRANSIENTS
%                     3-phase short-circuit fault
%                        Transient stability
clc
disp(date)

global Ra X Xmd Rf Rkd Rkq Hi Tl wo V vf0 tg tc 

smdata

disp('     MACHINE PARAMETERS in per unit:            ')
disp('   Ra         Xd        Xq         Xal  ')
disp([Ra Xd Xq Xal])
disp('    Rf        Xfl       Rkd       Xkdl        Rkq       Xkql   ')
param1=[Rf Xfl Rkd Xkdl Rkq Xkql] ; 
disp(param1)
disp('     H ')
disp(Hi)
%
disp('     V         I      power factor   ')   
param2=[V I pf];
disp(param2)
                    thetapf=acos(pf);
                    
%  --------------------- MODE OF OPERATION  (motor convention) --------------
%              theta=thetapf    <=== under-excited motor (lagging pf).
%              theta=-thetapf   <=== over-excited motor  (leading pf).
%              theta=thetapf-pi <=== over-excited  generator (lagging pf).
%              theta=-thetapf+pi<=== under-excited  generator (leading pf).
s1='Under-excited motor'; s2='Over-excited motor';          
s3='Over-excited generator'; s4='Under-excited generator';
k=menu('Choose operating mode:',s1,s2,s3,s4);
      if k==1
                  theta=thetapf;    mode=s1;
      elseif k==2
                  theta=-thetapf;   mode=s2;
      elseif k==3
                  theta=thetapf-pi; mode=s3;
      elseif k==4
                  theta=-thetapf+pi;mode=s4;
      end
      
%        Steady-state calculation of operating point:                  
    j=sqrt(-1);
    Xmd=Xd-Xal;Xmq=Xq-Xal ;
    Eq1=V-(Ra+j*Xq)*I*exp(-j*theta);
    delta0=-angle(Eq1);
    Eq=abs(Eq1);
    Ia=I*exp(j*(pi/2+delta0-theta));
    Vt=V*exp(j*(pi/2+delta0))      ;
        id0=real(Ia) ; iq0=imag(Ia)  ;
        vd0=real(Vt) ; vq0=imag(Vt)  ;
    Ef0=vq0-Ra*iq0-Xd*id0; if0=Ef0/Xmd;
    Te0=Eq*iq0;
disp(' Operating point  (motor conventions)  :                ')
disp('   vd0       vq0        id0       iq0        if0       Te0 ')
disp([vd0 vq0 id0 iq0 if0 Te0]) 
disp('   delta0     theta0                      ')
disp([delta0*180/pi theta*180/pi])
x3=[vd0-.1 id0-.1 -.13 if0+.1];
y3=[vq0+.1 iq0+.1 Ef0 -.1];
phasor=['Vt' 
        'Ia' 
        'Ef'
        'If'];
h1=figure('Units','Normalized','menubar','none','Position',[.25 .45 .5 .5]); 
axis ('equal')
vecarrow([0 0],[0 Ef0],'c'),grid,hold on
vecarrow([0 0],[if0 0],'g')
vecarrow([0 0],[id0 iq0],'r')
vecarrow([0 0],[vd0 vq0],'k')
plot(0,0,'xk')
title(' PHASORS  along d-q axes','color','b','fontsize',14)
v=axis;
text(x3,y3,phasor),text(.45*v(2),.7*v(4) ,mode,'color',[.9 .1 .5],'fontsize',11),hold off,pause(3)

%                  TRANSIENT OPERATION     
   Ra=Ra+Rth ;Xal=Xal+Xth;

   X=[Xal+Xmd    0     Xmd     Xmd       0
          0    Xal+Xmq   0       0       Xmq
         Xmd       0      Xmd+Xfl Xmd      0
         Xmd       0      Xmd    Xmd+Xkdl  0
         0       Xmq      0       0        Xmq+Xkql]

%     Initial conditions:
           phid=Xd*id0+Xmd*if0   ;  phiq=Xq*iq0 ;
           phif=(Xmd+Xfl)*if0+Xmd*id0;
           phikd=Xmd*(id0+if0)   ; phikq=Xmq*iq0;
           n=1.0 ;   Tl=Te0      ; vf0=Rf*if0   ;
fo=[phid phiq phif phikd phikq n delta0]';
disp('                         Initial state:                  ')
disp(fo)
tspan=[0 tf];

%%%%%% ODE %%%%%%%%%
options=odeset('RelTol',1e-3,'maxstep',5e-4);  %,'outputfcn','odeplot','outputsel',7) ;
[t,f]=ode23(@smeq,tspan,fo,options); 
%           Output vectors: 
            flux=f(:,1:5)'; cur=X\flux;
            spd=f(:,6);
            delta=-f(:,7)*180/pi;
            id=cur(1,:)';
            iq=cur(2,:)';
            Te=iq.*f(:,1)-id.*f(:,2);
            iff=cur(3,:)';
            ias=id.*cos(wo*t-f(:,7)+bet)-iq.*sin(wo*t-f(:,7)+bet);
            ibs=id.*sin(wo*t-f(:,7)+bet)+iq.*cos(wo*t-f(:,7)+bet);
            Is=sqrt(ias.^2+ibs.^2);
            iB=-ias/2+sqrt(3)/2*ibs;
            iC=-ias/2-sqrt(3)/2*ibs;

%  ---------------------------------- PLOTS  ------------------------------------
figure(3);plot(t,Te,'m'),xlabel('TIME [s]'),ylabel('TORQUE [pu]'),grid
figure(4);plot(t,delta,'g'),xlabel('TIME [s]'),ylabel('TORQUE ANGLE \delta [o]'),grid
figure(5);plot(delta,spd,'b'),xlabel('TORQUE ANGLE \delta [o]'),ylabel('SPEED \omega_m [pu]'),grid
figure(6);plot(t,iff,'g'),xlabel('TIME [s]'),ylabel('FIELD CURRENT [pu]'),grid
figure(7);plot(t,ias,'r',t,Is,'-k'),xlabel('TIME [s]'),ylabel('STATOR CURRENT iA [pu]'),grid
figure(8);plot(t,id,'r',t,iq,'b'),xlabel('TIME [s]'),ylabel('DQ CURRENTS [pu]'),grid,legend('id','iq',4)
figure(9);plot(id,iq,'r'),title('STATOR CURRENT SPACE VECTOR IN DQ FRAME'),grid,axis ('equal')
% -----------------------------------------------------------------------------

