%                <<<   INDUCTION MOTOR TRANSIENTS  >>>
%          Motor is initialized at a specified operating condition
clear,clc
disp('        <<<    Induction motor transients  >>>         ')
disp('               [ Sinusoidal excitation  ]              ')
disp('               ( per-unit formulation  )               ')
% ---------------------------  DATA  ------------------------------------------
%           Machine parameters in per unit:                            
Rs=0.01 ; %Stator resistance
Rr=0.02 ; %Rotor resistance
Lsl=0.1 ; %Stator leakage inductance
Lrl=0.1 ; %Rotor leakage inductance
Lm=4.5  ; %Magnetizing inductance 
vs=1.0  ; %Stator voltage
gam=0;    %Phase (rad)
ws=1.0  ; %Stator frequency
freq0=60; %Base frequency (Hz)
H=0.30  ; %Inertia constant (s)
Bm=1e-5 ; %Torque speed coefficient

n0=0.98 ; %Speed that defines steady-state operating conditions

% --------------------  STEADY-STATE PHASOR CALCULATIONS  --------------------
     disp('          Parameters of induction machine in per unit    ')
disp('                                                         ')
disp('    Rs        Lsl       Rr        Lrl       Lm       vs         ws')
param=[Rs Lsl Rr Lrl Lm vs ws];
disp(param)
wo=2*pi*freq0;    
Ls=Lsl+Lm ; Lr=Lrl+Lm;

%-------------- IC calculations -------------------------------------------

wk=ws;                                % synchronous frame

V=[vs*cos(gam) vs*sin(gam) 0 0]';     % Voltage vector

 R=diag([Rs Rs Rr Rr]);               % Resistance matrix   
       
 L=[Ls  0   Lm  0   
    0   Ls  0   Lm 
    Lm  0   Lr  0
    0   Lm  0   Lr];                  % Inductance matrix
    
    rot90=[0 -1;1 0];    O=zeros(2);        
    
  W=[wk*rot90       O                  % Frame speed matrix ...
        O    (wk-n0)*rot90];           % with respect to stator and rotor      
    
  Z=R+W*L;                             % Impedance (real) matrix
  
  I=Z\V;                               % Current vector

  F=L*I;                               % Flux vector  
  
  Tl0=Lm*(I(2)*I(3)-I(1)*I(4));        % Electromagnetic torque (average)

    op=[n0  Tl0];    disp('       n0     Tl0  ')  
    disp(op)
   
    ic=F;
% --------------------------------------------------------------------------------
%==> IF YOU MODIFY THE PARAMETERS, SAVE THE FILE AND DOUBLE CLICK THE PARAMETERS BLOCK;
%==> CLOSE THIS WINDOW;
%==> RUN THE MDL FILE;