%                <<<   INDUCTION MOTOR TRANSIENTS  >>>
clear,clc
disp('                                                         imdefrotflux.m')
disp('        <<<    Induction motor transients  >>>         ')
disp('               [ Sinusoidal excitation  ]              ')
disp('               ( per-unit formulation  )               ')
% ---------------------------  DATA  ------------------------------------------
%           Machine parameters in per unit:                            
Rs=0.01 ; %Stator resistance
Rr=0.02 ; %Rotor resistance
Lsl=0.1 ; %Stator leakage inductance
Lrl=0.1 ; %Rotor leakage inductance
Lm=4.5  ; %Magnetizing inductance 
vs=1.0  ; %Stator voltage
ws=1.0  ; %Stator frequency
freq0=60; %Base frequency (Hz)
H=0.30  ; %Inertia constant (s)
Bm=1e-5 ; %Torque speed coefficient

n0=0.98 ; %Speed (establishes operating point)

% --------------------  STEADY-STATE PHASOR CALCULATIONS  --------------------
     disp('          Parameters of induction machine in per unit    ')
disp('                                                         ')
disp('    Rs        Lsl       Rr        Lrl       Lm       vs         ws')
param=[Rs Lsl Rr Lrl Lm vs ws];
disp(param)
wo=2*pi*freq0;
wk=ws;
Ls=Lsl+Lm ; Lr=Lrl+Lm;
j=sqrt(-1);
    Zr=Rr/(ws-n0)+j*Lrl; Zm=j*Lm*Zr/(j*Lm+Zr);  Zin=Rs/ws+j*Lsl+Zm;
    Is=vs/(ws*Zin);  Ir=-Is*j*Lm/(j*Lm+Zr);
    Req=real(Zm);    Tl0=Is*conj(Is)*Req;
    phis=Ls*Is+Lm*Ir;  phir=Lm*Is+Lr*Ir; 
    phids=real(phis);  phiqs=imag(phis);
    phidr=real(phir);  phiqr=imag(phir);
    op=[n0  Tl0];    disp('       n      Tl  ')  
    disp(op)
    fr0=sqrt(phidr^2+phiqr^2);  
    an=atan2(phiqr,phidr) ;         
    fs0d=phids*cos(an)+phiqs*sin(an); fs0q=-phids*sin(an)+phiqs*cos(an);
    fs0=[fs0d fs0q];
% ----------------------------------------------------------------------------