%                           Single-phase induction motor
%                              Capacitor type
%                           Steady-state conditions
close all,clear,clc
disp(date)
disp('                                                      imssdqcap.m ')
disp(' <<<  Single-phase capacitor induction motor  >>>  ')
disp(' <<<  Steady-state characteristics >>>  ')
disp('')                                             
% --------------- Machine parameters (SI units): ---------------------------
%                Rating: 1/4-hp, 4-pole, 60-Hz, 110-V(rms)
            Ras1=7.14  ; Xal=4.22;            % Auxiliary winding
            Rbs=2.020  ; Xbl=2.79;            % Main winding
            Rr =4.12   ; Xrl=2.12;            % Rotor (referred to stator)
            Xm=66.8    ;
            Ropen =1e8 ;                      % Open circuit
            Rstart=3.00; Xstart=-14.5;        % Starting capacitor
            Rrun  =9.00; Xrun  =-172 ;        % Running capacitor
            j=sqrt(-1); Vas=110 ;  Vbs=110 ;  
            fs=1.0; freq0=60.0;freq=fs*freq0;p=4;
disp('    Ras       Xal       Rbs       Xls       Rr        Xrl        Xm    ')
param=[Ras1 Xal Rbs Xbl Rr Xrl Xm];
exc=[Vas Vbs freq];
disp(param)
disp('   Vas   Vbs    freq         ')
disp(exc)
           Xas=Xal+Xm ; Xbs=Xbl+Xm ; Xr=Xrl+Xm ;
           wsync=4*pi*freq/p;
for k=1:3
        if k==1, Ras=Ras1+Rstart; Xas=Xal+Xstart+Xm;
    elseif k==2, Ras=Ras1+Rrun  ; Xas=Xal+Xrun+Xm  ; 
    elseif k==3, Ras=Ropen      ; 
    end
    wmm=[0:0.01:1];                      % adjust speed range on this line
for m=1:size(wmm,2)                          % # of steps
   n=wmm(m);
% Z matrix ----------------------------------------------------------------------
  Z=[Ras+j*fs*Xas          0           j*fs*Xm       0        
         0            Rbs+j*fs*Xbs         0       j*fs*Xm    
      j*fs*Xm              n*Xm       Rr+j*fs*Xr   n*Xr       
      -n*Xm             j*fs*Xm        -n*Xr     Rr+j*fs*Xr];
% -------------------------------------------------------------------------------
     V=[Vas Vbs 0 0].';  I=Z\V;
  Ias(k,m)=abs(I(1)); Ibs(k,m)=abs(I(2));Iline(k,m)=abs(I(1)+I(2));
  spd(m)=n*wsync*30/pi;
  Te(k,m)=Xm/wsync*real(I(2)*conj(I(3))-I(1)*conj(I(4)));   % T_average
  Tp(k,m)=Xm/wsync*abs(I(2)*I(3)-I(1)*I(4));                % T_pulsating
  end
end
% ----------------------- GRAPHS  ------------------------------------------
h=figure('Position',[20 40 980 460],'Name','Capacitor motor characteristics',...
    'NumberTitle','off');
 figure(h)
subplot(221),plot(spd,Te(1,:),spd,Te(2,:),spd,Te(3,:)),
xlabel('SPEED [rpm]'),ylabel('TORQUE [N.m]'),grid
subplot(222),plot(spd,Tp(1,:),spd,Tp(2,:),spd,Tp(3,:)),
xlabel('SPEED [rpm]'),ylabel('PULSATING TORQUE [N.m]'),grid
subplot(223),plot(spd,Ias(1,:),spd,Ias(2,:),spd,Ias(3,:)),
  xlabel('SPEED [rpm]'),ylabel('I_auxiliary [A]'),grid 
subplot(224),plot(spd,Ibs(1,:),spd,Ibs(2,:),spd,Ibs(3,:)),
   xlabel('SPEED [rpm]'),ylabel('I_main [A]'),grid 
%subplot(224),plot(spd,Iline(1,:),spd,Iline(2,:),spd,Iline(3,:)),
%xlabel('SPEED [rad/s]'),ylabel('I_line [A]'),grid
