%  V/f control of IM [SI]
clc,clear
% ~~~~~~~~~~~~~~~~~~~ DATA (SI)~~~~~~~~~~~~~~~~~
Vll=220    ; %Line-to-line rms voltage rating [V]
HP=10.0    ; %Horsepower rating [hp]
Rs=0.1%.294   ; %Stator resistance (Ohm)
Rr=0.144   ; %Rotor resistance  (Ohm)
fo=60      ; %Base frequency (Hz)
wo=2*pi*fo ; %Base frequency (rad/s)
Lsl=0.00134; %Stator leakage inductance (H)
Lrl=0.554e-3;%Rotor leakage inductance  (H)
Lm=0.0353  ; %Magnetizing inductance  (H) 
p=6 ;        %number of poles
d=0.0;      %factor introduced to compensate ... 
             %for effects of Rs at low frequencies
n2=1.2; dn=0.1; n1=-1;  % frequency steps           
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 

Vn=Vll/sqrt(3); %Base voltage L-n rms 
Zmag=Rr+j*wo*(Lm+Lsl);
Imag=abs(Vn/Zmag);
%f=[n1:dn:n2];
f=[-.9 -.8 -.7 -.6 -.5 -.4 -.3 -.2 .2 .3 .4 .5 .6 .7 .8 .9 1 1.1 1.2]
v=abs((1-d)*f+d);
co=['bbgmckybgcrkkcybgrmck'];

figure('Units','Normalized','Position',[.03 .1 .8 .77],...
     'Name','CONSTANT Volts/Hertz CHARACTERISTICS OF IM','NumberTitle','on')
 
 L=length(f);
 for k=1:L
   if abs(f(k))>1, v(k)=1; end
   if f(k)==0, f(k)=.0001; end
    n=n1:.001:n2%f(k)+0.01;
    Zr=Rr*f(k)./(f(k)-n+eps)+j*Lrl*wo*f(k);
    Zf=j*wo*Lm*f(k).*Zr./(j*Lm*wo*f(k)+Zr+eps);
    Zin=Rs+j*wo*Lsl*f(k)+Zf;
    Rf=real(Zf); 
    Is=v(k)*Vn./Zin;  %rms
    Te=1.5/wo*p*(Is.*conj(Is)./(f(k)+eps).*Rf);
    Is=abs(Is);
    if n<0, g=Te<0,Te=g.*Te; end
    Tm(k)=max(Te);
    q=find(max(Te)==Te);
 speed=n*120*fo/p;
    nm(k)=speed(q);
 spd2=n2*120*fo/p; 
 spd1=n1*120*fo/p;
   
h1=subplot(211);
    plot(speed,Te,co(k)),grid,title('V/f control of induction motor','color','r','fontsize',14),
    xlabel('SPEED [rpm] '),ylabel('TORQUE [N-m]'),hold on
    plot(nm,Tm,'--b'),legend('Tmax')
    set(gca,'Xlim',[spd1 spd2])%,'Ylim',[-inf inf]) 
    set(findobj(gca,'type','line','color','r'),'linewidth',2)
    
      pause(0.3)
      
 subplot(212)
    plot(speed,Is,co(k)),grid,
    xlabel('SPEED [rpm] '),ylabel('CURRENT [A]'),hold on
    set(gca,'Xlim',[spd1 spd2]) 
    set(findobj(gca,'type','line','color','r'),'linewidth',2)   
   
end 

legend('0.1','0.2','0.3','0.4','0.5','0.6','0.7','0.8','0.9','1.0','1.1','1.2')
line([spd1 spd2],[Imag Imag],'color','r','linestyle',':')
text(20,Imag+10,'~Imag','color','r')
vo(1)={'V [pu]'};
vo(2)={'-----'};
vv=num2str(v(2:L)');
vo(3)={vv};
bb=Xlim;  cc=Ylim;
text(.92*bb(2),1.07*cc(2),'f [pu]','color','m')
text(1.02*bb(2),.61*cc(2),vo,'color','b')

uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','edit imvf', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ... 
	'Position',[0.08 0.01 0.07 .04], ...
	'String','Edit', ...
    'TooltipString','edit'); 
uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','close all,clc,clear', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.9 0.01 0.07 .04], ...
	'String','Close', ...
    'TooltipString','close'); 
uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','imvf', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.2 0.01 0.07 .04], ...
	'String','Run', ...
    'TooltipString','run'); 