%           Synchronous machine steady-state characteristics   <smss1.m>
clear,clc,close all
disp(date)
disp('           <<<  SYNCHRONOUS MACHINE CHARACTERISTICS  >>> ')

disp('   INPUT  MACHINE PARAMETERS in per unit:  ')
%          Machine parameters (pu) :
Ra=input('Armature resistance Ra  (default = 0.005) =');
    if isempty(Ra)==1 Ra=0.005; end; 
Xd=input('Direct-axis reactance Xd (default = 1.15) =');
    if isempty(Xd)==1 Xd=1.15; end;     
Xq=input('Quadrature-axis reactance Xq (default = 0.75) =');
    if isempty(Xq)==1 Xq=0.75; end; 
    if Xq==Xd, Xq=1.0001*Xd; end    
Vt=input('Armature resistance Vt (default = 1.0) =');
    if isempty(Vt)==1 Vt=1.0; end;
fs=input('Base frequency fs (default = 1.0) =');
    if isempty(fs)==1 fs=1.0; end; 
Ef=input('Seven values of Ef (default([0 0.25 .5 .75 1 1.5 2]) =');
    if isempty(Ef)==1 Ef=[0 0.25 .5 .75 1 1.5 2]; end;     
disp('      Ra        Xd        Xq        Vt        fs')
disp([Ra Xd Xq Vt fs])
disp('         Range of excitation voltage Ef:')
disp(Ef(1:7))
 
 co=['rbgmcyk']; %color scheme
 j=sqrt(-1); den=Xd*Xq+Ra*Ra/(fs*fs); 
 
figure('Units','normalized','Position',[.256 .05 .489 .32],...
    'Name','Synchronous machine characteristics','numbertitle','on','menubar','none');  
 for q=1:7 
     plot([q q],[0 Ef(q)],co(q)),title('Excitation voltage Ef','color','b','fontsize',12),
         ylabel('Ef (k)'),grid,hold on
     set(gca,'Xtick',1:7,'Ytick',0:0.25:2)
     h=findobj(gca,'Type','line');
     set(h,'LineWidth',5)
     plot(1.08,0.01,'squarer')
 end 

 uicontrol('Units','normalized', ...
	'Callback','clc,clear, close all', ...
	'FontSize',12, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 0.5], ...
	'Position',[0.15 0.84 0.09 0.07], ...
	'String','Close', ...
   'TooltipString','Close');   

for p=1:4
  for k=1:7
     del=-180:2:180;
     delta=del*pi/180;
     vd=-Vt*sin(delta); vq=Vt*cos(delta);
     id=(Xq*(Vt/fs*cos(delta)-Ef(k))-Ra*Vt*sin(delta)/(fs*fs))/den;
     iq=(Xd*Vt*sin(delta)/fs+Ra*(Vt*cos(delta)/fs-Ef(k)))/den;
     Te=Ef(k)*iq+(Xd-Xq)*id.*iq;
     P=id.*vd+iq.*vq ;
     Ia=id+j*iq; V=vd+j*vq; Imag=abs(Ia);
     theta=angle(Ia)-angle(V);
     Ireal=Imag.*cos(theta); Iimag=Imag.*sin(theta);
% ----------------------   PLOTS  ----------------------------------
   if p==1
    figure(2)
    plot(del,Te,co(k)),hold on
    xlabel('TORQUE ANGLE \delta [o]'),ylabel('TORQUE [pu]')
    set(gca,'Xlim',[-180 180],'Xtick',-180:60:180),grid
   end
   if p==2
   figure(3)   
    plot(del,P,co(k)),hold on
    xlabel('TORQUE ANGLE \delta [o]'),ylabel('POWER [pu]')
    set(gca,'Xlim',[-180 180],'Xtick',-180:60:180),grid
   end
   if p==3
    figure(4)  
    plot(del,Imag,co(k)),hold on
    xlabel('TORQUE ANGLE \delta [o]'),ylabel('CURRENT [pu]')
    set(gca,'Xlim',[-180 180],'Xtick',-180:60:180),grid
    end
    if p==4
      figure(5)
            plot(0,0,'ok',Ireal,Iimag,co(k)),grid,hold on
            vecarrow([0 0],[Vt 0],'b')
            text(Vt-.2,-.15,'Vt','color','b'),title('CURRENT PHASOR LOCI','color','r','fontsize',12)
            axis ('equal')
    end
  end
 end
%%%%%%%%%%%